Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(249)

Unified Diff: third_party/pkg/angular/lib/filter/json.dart

Issue 256553002: Revert "Update all Angular libs (run update_all.sh)." (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/pkg/angular/lib/filter/filter.dart ('k') | third_party/pkg/angular/lib/filter/limit_to.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/pkg/angular/lib/filter/json.dart
diff --git a/third_party/pkg/angular/lib/formatter/json.dart b/third_party/pkg/angular/lib/filter/json.dart
similarity index 50%
rename from third_party/pkg/angular/lib/formatter/json.dart
rename to third_party/pkg/angular/lib/filter/json.dart
index 8bc45666d835ae38ea85a0f518ad7382bc3f2a10..f2c0efa80dfcf2c1c93dbf09fd12b6d27c6366f2 100644
--- a/third_party/pkg/angular/lib/formatter/json.dart
+++ b/third_party/pkg/angular/lib/filter/json.dart
@@ -1,14 +1,14 @@
-part of angular.formatter_internal;
+part of angular.filter;
/**
* Allows you to convert a JavaScript object into JSON string. This formatter is
* mostly useful for debugging.
*
* Usage:
*
* {{ json_expression | json }}
*/
-@Formatter(name:'json')
-class Json implements Function {
- String call(jsonObj) => JSON.encode(jsonObj);
+@NgFilter(name:'json')
+class JsonFilter {
+ call(text) => JSON.encode(text);
}
« no previous file with comments | « third_party/pkg/angular/lib/filter/filter.dart ('k') | third_party/pkg/angular/lib/filter/limit_to.dart » ('j') | no next file with comments »
@@ -1,14 +1,14 @@
/**
- * Allows you to convert a JavaScript object into JSON string. This formatter is
+ * Allows you to convert a JavaScript object into JSON string. This filter is
* mostly useful for debugging.
*

Powered by Google App Engine
This is Rietveld 408576698